function varargout = EQ3bandes_TP(varargin)
% EQ3BANDES_TP MATLAB code for EQ3bandes_TP.fig
%      EQ3BANDES_TP, by itself, creates a new EQ3BANDE or raises the existing
%      singleton*.
%
%      H = EQ3BANDES_TP returns the handle to a new EQ3BANDES_TP or the handle to
%      the existing singleton*.
%
%      EQ3BANDES_TP('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in EQ3BANDES_TP.M with the given input arguments.
%
%      EQ3BANDES_TP('Property','Value',...) creates a new EQ3BANDES_TP or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before EQ3bandes_TP_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to EQ3bandes_TP_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help EQ3bandes_TP

% Last Modified by GUIDE v2.5 07-Nov-2016 13:40:41

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
    'gui_Singleton',  gui_Singleton, ...
    'gui_OpeningFcn', @EQ3bandes_TP_OpeningFcn, ...
    'gui_OutputFcn',  @EQ3bandes_TP_OutputFcn, ...
    'gui_LayoutFcn',  [] , ...
    'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before EQ3bandes_TP is made visible.
function EQ3bandes_TP_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to EQ3bandes_TP (see VARARGIN)

% Choose default command line output for EQ3bandes_TP
global AFR;
global ADW;
global frameLength;
global stop_button;
global pause_button;

handles.output = hObject;

set(handles.slider1,'Value',0);
set(handles.slider2,'Value',0);
set(handles.slider3,'Value',0);

stop_button = 0;
pause_button = 0;

frameLength = 256;

AFR = dsp.AudioFileReader('music.wav','SamplesPerFrame',frameLength);

ADW = dsp.AudioPlayer(AFR.SampleRate);


% Update handles structure
guidata(hObject, handles);







% UIWAIT makes EQ3bandes_TP wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = EQ3bandes_TP_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;
global AFR;
global ADW;
release(AFR);  % close the input file
release(ADW);  % close the audio output device



% --- Executes on slider movement.
function slider1_Callback(hObject, eventdata, handles)
% hObject    handle to slider1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
guidata(hObject, handles);



% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider


% --- Executes during object creation, after setting all properties.
function slider1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end
guidata(hObject, handles);


% --- Executes on slider movement.
function slider2_Callback(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function slider2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on slider movement.
function slider3_Callback(hObject, eventdata, handles)
% hObject    handle to slider3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider
guidata(hObject, handles);


% --- Executes during object creation, after setting all properties.
function slider3_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)


global AFR;
global ADW;
global frameLength;
global stop_button;
global pause_button;

fe = AFR.SampleRate;

fenetre = 'hann';
ordre = 100;
fcBass = 500;
fcAigu = 2000;

audio = zeros(frameLength,1);

while ~isDone(AFR) && stop_button == 0
    pause(1e-6);% ugly hack to push the event queue
    if pause_button == 0
        
        
        audio_pass = audio;
        audio = step(AFR);
        audio = mean(audio,2);
        
        audio_pad = [audio_pass;audio];
        
        
        gainBass = get(handles.slider1,'Value');
        gainMedium = get(handles.slider2,'Value');
        gainAigu = get(handles.slider3,'Value');
        
        pause(1e-6);% ugly hack to push the event queue
        
        [FIRcoeffBass] = coeff_passe_bas_fir(fe,fcBass,ordre,fenetre,gainBass,6);
        [FIRcoeffMedium] = coeff_passe_bande_fir(fe,fcBass,fcAigu,ordre,fenetre,gainMedium,6);
        [FIRcoeffAigu] = coeff_passe_haut_fir(fe,fcAigu,ordre,fenetre,gainAigu,6);
        
        audio_Bass  = realTime_filtering(audio_pad,frameLength,FIRcoeffBass);
        audio_Medium  = realTime_filtering(audio_pad,frameLength,FIRcoeffMedium);
        audio_Aigu  = realTime_filtering(audio_pad,frameLength,FIRcoeffAigu);
        
        audio_Eq = audio_Bass + audio_Medium + audio_Aigu;
        
        %fprintf('gainBass : %f \n',gainBass);
        
        
        step(ADW, audio_Eq);
    end
end


% --- Executes on button press in pushbutton2.
function pushbutton2_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global pause_button;

pause_button = ~pause_button;


% --- Executes on button press in pushbutton3.
function pushbutton3_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
global stop_button;

stop_button = ~stop_button;
